<?php
// $Id: discussthis.admin.inc,v 1.1.2.6 2009/12/04 12:37:04 alexiswilke Exp $
/**
 * @file
 *
 * Settings callbacks
 */


/**
 * Admin settings callback (from menu hook)
 * The admin/settings/discussthis page provides three sets of configuration options:
 * 1. The author of newly-created forum discussions
 * 2. The set of node types for which Discuss This! links should appear
 * 3. For each selected node type, a default forum in which to create discussion topics
 * @return discussthis settings edit form
 */
function discussthis_admin_settings() {
  drupal_add_js(drupal_get_path('module', 'discussthis') . '/discussthis.js');
  drupal_add_css(drupal_get_path('module', 'discussthis') . '/discussthis.css');

  $node_types = node_get_types('names');
  $discussthis_nodetypes = variable_get('discussthis_nodetypes', $node_types);

// the author, subject, body & # of comments
  $form['discussthis'] = array(
    '#type'        => 'fieldset',
    '#title'       => t('Automatic forum message settings'),
    '#description' => t('Setup the forum message that is created automatically when a new discussion is started.'),
    '#collapsible' => TRUE,
    '#collapsed'   => TRUE,
  );

  $form['discussthis']['discussthis_author'] = array(
    '#type'              => 'textfield',
    '#title'             => t('Author of newly created Forum discussions'),
    '#description'       => t('Leave blank if you want the person who clicks the link to be the author of the new topic. Note that if the author doesn\'t have permissions to edit their own topics, they won\'t be able to update the main topic itself, and if they don\'t have perms to post comments, they will not be able to actually submit a comment on the newly-created forum topic.'),
    '#size'              => 30,
    '#maxlength'         => 60,
    '#autocomplete_path' => 'user/autocomplete',
    '#default_value'     => variable_get('discussthis_author', ''),
    '#weight'            => -4,
  );

  $form['discussthis']['discussthis_newsubject'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Title for newly created Forum discussions'),
    '#size'          => 30,
    '#maxlength'     => 60,
    '#default_value' => variable_get('discussthis_newsubject', '[node-title]'),
    '#weight'        => -3,
  );

  $default_body  = DISCUSSTHIS_DEFAULT_NODE_MESSAGE;
  $form['discussthis']['discussthis_newtemplate'] = array(
    '#type'          => 'textarea',
    '#title'         => t('Template for auto-created Forum discussions'),
    '#description'   => theme('token_help', 'discussthis'),
    '#default_value' => variable_get('discussthis_newtemplate', $default_body),
    '#weight'        => -2,
  );

  $form['discussthis']['discussthis_comments'] = array(
    '#type'          => 'select',
    '#title'         => t('Number of comments to display'),
    '#description'   => t('This is only used in non-teaser view'),
    '#options'       => array(0 => 'none', 1 => '1', 2 => '2', 3 => '3', 4 => '4', 5 => '5', 10 => '10'),
    '#default_value' => variable_get('discussthis_comments', 10),
  );

  $form['discussthis']['discussthis_showcounts'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Show comment counts'),
    '#description'   => t('When checked, show the number of comments in the discussion (new/total)'),
    '#default_value' => variable_get('discussthis_showcounts', 1),
  );

  $form['discussthis']['discussthis_login'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Login/Register link for Anonymous users'),
    '#description'   => t('Check this box to offer anonymous users to login/register when on a page with the Discuss this feature. Note: this will have no effect if anonymous users do not have the "access discuss this links" permission. If your registration process is complicated, you may want to turn this feature off.'),
    '#default_value' => variable_get('discussthis_login', 1),
  );

// the forum/node type table
  $form['discussthis_forums'] = array(
    '#type'           => 'fieldset',
    '#title'          => t('Node type & forum selection'),
    '#description'    => t('Defines the forum attached to each node type. Leave a node type unchecked if you do not want Discuss This! on these nodes.'),
    '#collapsible'    => TRUE,
    '#collapsed'      => FALSE,
  );

  $form['discussthis_forums']['discussthis_nodetypes'] = array(
    '#type'          => 'checkboxes',
    '#title'         => t('Node types using Discuss This'),
    '#description'   => t('Select all node types where the Discuss This link will appear, and a corresponding Default forum in which to create the topic.'),
    '#default_value' => $discussthis_nodetypes,
    '#options'       => $node_types,
  );

  $forums = forum_get_forums();
  $discussthis_forums = array('0' => '-- select --');
  foreach ($forums as $tid => $forum) {
    if (!$forum->container) {
      $discussthis_forums[$tid] = str_repeat('-', $forum->depth) . $forum->name;
    }
  }

  // This should probably be within the node type config page, or else use some AJAX thingy to update
  // these form fields based on the discussthis_nodetypes selection above..
  foreach ($discussthis_nodetypes as $type => $name) {
    $form['discussthis_forums']['defaults']['discussthis_node_'. $type] = array(
      //'#title'         => 'Forum for '. $node_types[$type], -- when it works, this appears under the checkbox when the checkbox is checked
      '#type'          => 'select',
      '#default_value' => variable_get('discussthis_node_'. $type, 0),
      '#options'       => $discussthis_forums,
      '#prefix'        => '<span class="conditional">',
      '#suffix'        => '</span>',
    );
  }

  $form['discussthis_forums']['#theme'] = 'discussthis_admin_settings_forums';

// Now process the form
  return system_settings_form($form);
}


/**
 * Make sure that every node-type selected also has a default Forum topic
 **/
function discussthis_admin_settings_validate($form, &$form_state) {
  $node_types = node_get_types('names');
  foreach ($form_state['values']['discussthis_nodetypes'] as $type => $enabled) {
    if ($enabled && $form_state['values']['discussthis_node_'.$type] == 0) { # The node type is enabled but has no default forum
      form_set_error('discussthis_node_'. $type, t('Please select a default Forum for @type nodes.',
        array('@type' => $node_types[$type])));
    }
  }
}


/**
 * Render the admin settings page so that the required default Form
 * dropdowns are immediately beside the checkboxes
 *
 * TODO: That would certainly be neat, but at this time it ain't working
 * for D6.
 **/
function theme_discussthis_admin_settings_forums($element) {
  $types = '<ul>';
  foreach ($element['discussthis_nodetypes']['#options'] as $type => $name) {
    $types .= '<li>';
    $types .= drupal_render($element['discussthis_nodetypes'][$type]);
    $types .= drupal_render($element['defaults']['discussthis_node_'. $type]);
    $types .= '</li>';
  }
  $types .= '</ul>';

  return drupal_render($element['discussthis_nodetypes']) . $types;
}
